@@ -21,8 +21,8 @@ if TYPE_CHECKING:
 
 
 class CanFindElements(Protocol):
-    def find_element(self, by: str, value: Union[str, Dict] = None) -> 'WebElement':
+    def find_element(self, by: str, value: Union[str, Dict, None] = None) -> 'WebElement':
         ...
 
-    def find_elements(self, by: str, value: Union[str, Dict] = None) -> List['WebElement']:
+    def find_elements(self, by: str, value: Union[str, Dict, None] = None) -> List['WebElement']:
         ...
